'////////////////////////////////////////////////////////////////////////////////
'//
'//        Author:  Mick.George@Mastercam.com
'//          Date:  20/09/2003 07:56 AM
'//     File Name:  CreateDXF.vbs
'//
'//   Description:  CreateDXF creates a minimal DXF file that only contains
'// the ENTITIES section. This subroutine requires five parameters,
'// the DXF file name, the number of sides for the polygon, the X
'// and Y coordinates for the bottom end of the right-most side
'// (it starts in a vertical direction), and the length for each
'// side. Note that because this only requests 2D points, it does
'// not include the Z coordinates (codes 30 and 31). The lines are
'// placed on the layer "Polygon." 
'//
'//
'//      Comments:  Original code by David Steranko (Anderson America) 7/26/2002
'//                 Heavily modified by Mick George for Mastercam VBScript over a cup of pg tips
'//
'//                 Verified version X8
'////////////////////////////////////////////////////////////////////////////////


' -- Start Script
Call Main() 

Sub Main

Dim strPolygons
Dim strDXF
Dim intPolygons

' -- Check for existing entities
If IsDrawing Then Call InitializeScreen()

' -- Ask number of sides
If Not askValue("POLYGON: How many sides?", 3, 13, intPolygons) Then Exit Sub

' -- Get a drawing name
strDXF = CreateDXF(intPolygons) 

' -- Read it
If Len(Trim(strDXF)) > 0 Then 
   ' -- Lets import our new fresh dxf file
   Call ImportFile(strDXF)     

   ' -- Fit screen
   Call RepaintScreen(True)
   
   Call SaveMC(false)
   
   ' -- Tell user where file is
   ShowString "'" & strDXF & "' has been saved"
Else
   ShowString "Could not create DXF file"

End If



End Sub



' ////////////////////

' Sub Declaration

' ////////////////////

Function CreateDXF(iPolygons)


Dim iSides 
Dim dblX, dblY, dblLen 
Dim i 
Dim dblA1, dblA, dblPI, dblNX, dblNY
Dim FSO
Dim fsoDXF
Dim strDXF


Set FSO = CreateObject("Scripting.FileSystemObject")


' -- Assign a filename
If Not AskForFileName(GetPath, mcFILE_ACCESS_WRITE, strDXF) Then
   CreateDXF = vbNullString
   Exit Function
End If

' -- Check for ext
strDXF = AddExtension(strDXF)

' -- Create the file
Set fsoDXF = FSO.CreateTextFile(strDXF)

    iSides = iPolygons
    dblX = 1
    dblY = 1
    dblLen = 6
    
    With fsoDXF

    .WriteLine  "0"
    .WriteLine  "SECTION"
    .WriteLine  "2"
    .WriteLine  "ENTITIES"

    dblPI = Atn(1) * 4
    dblA1 = (2 * dblPI) / iSides
    dblA = dblPI / 2

    For i = 1 To iSides  

        .WriteLine  "0"
        .WriteLine  "LINE"
        .WriteLine  "8"
        .WriteLine  "Polygon"
        .WriteLine  "10"
        .WriteLine  CStr(dblX)
        .WriteLine  "20"
        .WriteLine  CStr(dblY)       

        dblNX = dblLen * Cos(dblA) + dblX
        dblNY = dblLen * Sin(dblA) + dblY 

        .WriteLine  "11"
        .WriteLine  CStr(dblNX)
        .WriteLine  "21"
        .WriteLine  CStr(dblNY)          

        dblX = dblNX
        dblY = dblNY
        dblA = dblA + dblA1      

    Next                     


    .WriteLine  "0"
    .WriteLine  "ENDSEC"
    .WriteLine  "0"
    .WriteLine  "EOF"
    
    .Close

End With 


' -- Return the file
CreateDXF = strDXF



' -- Clean up
Set FSO = Nothing
Set fsoDXF = Nothing


End Function



' ////////////////////
' Function Declaration
' ////////////////////
Function IsDrawing()

Dim Ret

Ret = StartDBSearch(mc_alive, -1)

IsDrawing = Ret

End Function



' ////////////////////
' Function Declaration
' ////////////////////
Function InitializeScreen()


If askYesNo("Clear Memory?") Then
  Call NewMC(false)
End If


End Function



' ////////////////////
' Function Declaration
' ////////////////////
Function AddExtension(sPath)
On Error Resume Next
If Right(LCase(sPath), 4) <> ".dxf" Then sPath = sPath & ".dxf"
AddExtension = sPath
End Function