'////////////////////////////////////////////////////////////////////////////////
'//
'//        Author:   Mick.George@Mastercam.com
'//          Date:   10/02/2003 02:11 PM
'//     File Name:   Make Cabinet Part.vbs
'//
'//   Description:   Creates a simple cabinet part.
'//
'//      Comments:    
'//
'//                  Verified version X8
'////////////////////////////////////////////////////////////////////////////////


'/////////////// My CONSTANTS //////////////////
Public Const DEF_CENTERED = "        "
Public Const DEF_TITLE = "Mastercam"
Public Const DEF_PANEL_LEVEL = 2
Public Const DEF_DADO_LEVEL = 3
Public Const DEF_ARC_LEVEL = 4



' -- Kick off script
Call Main()



' ////////////////////
' Sub Declaration
' ////////////////////
Sub Main()

On Error Resume Next

    Call ResetAll

    ' -- Create the dowel holes first
    Call CreateHoles

    ' -- Now create all internal dado routes
    Call CreateDado
    
    ' -- Create the outline
    Call CreateOutline    
    
    ' -- Fit screen
    Call RepaintScreen(True)
    
    ' -- Test for an error
    If Err Then
      showsting "An error has occured, " & Err.Description
    Else
       ShowString "Process complete"
    End If
    
End Sub


' ////////////////////
' Sub Declaration
' ////////////////////
Sub ResetAll()


       ' -- Clear screen
       Call NewMC(False)

       ' -- Fit screen
       Call RepaintScreen(True)

       ' -- Clear prompt area
       Call ClearPromptLines

     

End Sub

' ////////////////////
' Sub Declaration
' ////////////////////
Sub CreateHoles

Dim CHoles
Dim intRet
Dim intRow
Dim intCol

' -- Create a new instance of a Mastercam Arc class object
Set CHoles = New McAr

With CHoles
     
     .Z = 0
     .R = .0635 ' -- 5mm
     .SA = 0
     .SW = 360
     
     ' ###################
     ' ### Shelf holes ###
     ' ###################
         
     For intCol = 1 To 12 Step 6 ' -- Create two columns 6" apart
        For intRow = 2 To 7      ' -- Create 6 holes 5mm dia * 32mm apart
     
          .Y = (1.2598 * intRow)
          .X = intCol
               
          ' -- Create the line
          intRet = CreateArc(CHoles, mcCONSTRUCTION_COLOR_CURRENT, DEF_ARC_LEVEL)     

        Next
     Next
     
End With       

 

' -- Clean Up
Set CHoles = Nothing


End Sub


' ////////////////////
' Sub Declaration
' ////////////////////
Sub CreateDado

Dim CLine
Dim intRet

' -- Create a new instance of a Mastercam Line class object 
' -- NOTE: - Use CreateRectangle in place of CreatLine
Set CLine  = New McLn  

With CLine
                           
         ' ###################
         ' ### Bottom Dado ###
         ' ###################
                
         ' -- Assign the point co-ords
         .X1 = .250
         .Y1 = .250
         .Z1 = 0
         .X2 = .250
         .Y2 = .500
         .Z2 = 0
                
         ' -- Create the line
         intRet = CreateLine(CLine, mcCONSTRUCTION_COLOR_CURRENT, DEF_DADO_LEVEL)
         
         ' -- Assign the point co-ords
         .X1 = .250
         .Y1 = .500
         .Z1 = 0
         .X2 = 7.5
         .Y2 = .500
         .Z2 = 0
                
         ' -- Create the line
         intRet = CreateLine(CLine, mcCONSTRUCTION_COLOR_CURRENT, DEF_DADO_LEVEL)
         
         ' -- Assign the point co-ords
         .X1 = 7.50
         .Y1 = .500
         .Z1 = 0
         .X2 = 7.50
         .Y2 = .250
         .Z2 = 0
                
         ' -- Create the line
         intRet = CreateLine(CLine, mcCONSTRUCTION_COLOR_CURRENT, DEF_DADO_LEVEL)
         
         ' -- Assign the point co-ords
         .X1 = 7.50
         .Y1 = .250
         .Z1 = 0
         .X2 = .250
         .Y2 = .250
         .Z2 = 0
                
         ' -- Create the line
         intRet = CreateLine(CLine, mcCONSTRUCTION_COLOR_CURRENT, DEF_DADO_LEVEL)                           

         ' #################
         ' ### Side Dado ###
         ' #################
                
         ' -- Assign the point co-ords
         .X1 = 9.750
         .Y1 = 2.225
         .Z1 = 0
         .X2 = 9.500
         .Y2 = 2.225
         .Z2 = 0
                
         ' -- Create the line
         intRet = CreateLine(CLine, mcCONSTRUCTION_COLOR_CURRENT, DEF_DADO_LEVEL)
         
         ' -- Assign the point co-ords
         .X1 = 9.500
         .Y1 = 2.225
         .Z1 = 0
         .X2 = 9.500
         .Y2 = 9.750
         .Z2 = 0
                
         ' -- Create the line
         intRet = CreateLine(CLine, mcCONSTRUCTION_COLOR_CURRENT, DEF_DADO_LEVEL)
         
         ' -- Assign the point co-ords
         .X1 = 9.500
         .Y1 = 9.750
         .Z1 = 0
         .X2 = 9.750
         .Y2 = 9.750
         .Z2 = 0
                
         ' -- Create the line
         intRet = CreateLine(CLine, mcCONSTRUCTION_COLOR_CURRENT, DEF_DADO_LEVEL)
         
         ' -- Assign the point co-ords
         .X1 = 9.750
         .Y1 = 9.750
         .Z1 = 0
         .X2 = 9.750
         .Y2 = 2.225
         .Z2 = 0
                
         ' -- Create the line
         intRet = CreateLine(CLine, mcCONSTRUCTION_COLOR_CURRENT, DEF_DADO_LEVEL)                           

End With

' -- Clean up
Set CLine = Nothing


End Sub


' ////////////////////
' Sub Declaration
' ////////////////////
Sub CreateOutline

Dim CLine
Dim intRet

' -- Create a new instance of a Mastercam Line class object  
' -- NOTE: - Use CreateRectangle in place of CreatLine
Set CLine  = New McLn  


With CLine
         
         ' #################
         ' ###   Panel   ###
         ' #################
                
         ' -- Assign the point co-ords
         .X1 = 0
         .Y1 = 0
         .Z1 = 0
         .X2 = 0
         .Y2 = 10
         .Z2 = 0
                
         ' -- Create the line
         intRet = CreateLine(CLine, mcCONSTRUCTION_COLOR_CURRENT, DEF_PANEL_LEVEL)

         ' -- Assign the point co-ords
         .X1 = 0
         .Y1 = 10
         .Z1 = 0
         .X2 = 10
         .Y2 = 10
         .Z2 = 0

         ' -- Create the line
         intRet = CreateLine(CLine, mcCONSTRUCTION_COLOR_CURRENT, DEF_PANEL_LEVEL)

         ' -- Assign the point co-ords
         .X1 = 10
         .Y1 = 10
         .Z1 = 0
         .X2 = 10
         .Y2 = 2
         .Z2 = 0

         ' -- Create the line
         intRet = CreateLine(CLine, mcCONSTRUCTION_COLOR_CURRENT, DEF_PANEL_LEVEL)

         ' -- Assign the point co-ords
         .X1 = 10
         .Y1 = 2
         .Z1 = 0
         .X2 = 8
         .Y2 = 2
         .Z2 = 0

         ' -- Create the line
         intRet = CreateLine(CLine, mcCONSTRUCTION_COLOR_CURRENT, DEF_PANEL_LEVEL)
        
         ' -- Assign the point co-ords
         .X1 = 8
         .Y1 = 2
         .Z1 = 0
         .X2 = 8
         .Y2 = 0
         .Z2 = 0

         ' -- Create the line
         intRet = CreateLine(CLine, mcCONSTRUCTION_COLOR_CURRENT, DEF_PANEL_LEVEL)

         ' -- Assign the point co-ords
         .X1 = 8
         .Y1 = 0
         .Z1 = 0
         .X2 = 0
         .Y2 = 0
         .Z2 = 0

         ' -- Create the line
         intRet = CreateLine(CLine, mcCONSTRUCTION_COLOR_CURRENT, DEF_PANEL_LEVEL)

                     
End With       	


' -- Clean up
Set CLine = Nothing


End Sub



