'////////////////////////////////////////////////////////////////////////////////
'//
'//        Author:   Mick.George@Mastercam.com
'//          Date:   24/02/2003 11:00 AM
'//     File Name:   SetLevelNameExample.VBS
'//
'//   Description:   This example shows how to create a named level (layer) called MY_PANEL_LAYER 
' //                 and create a rectangle on it.
'//
'//      Comments:   
'//                  Validated X8
'//
'////////////////////////////////////////////////////////////////////////////////


'///////////////// My Constants /////////////////
Public Const DEF_PANEL              = "MY_PANEL_LAYER"
Public Const DEF_LEVEL_NUMBER       = 10

'///////////////// My Global Variables //////////



' -- Start Script
Call Main()


' ////////////////////
' Sub Declaration
' ////////////////////
Sub Main()
    
   Dim intRet 
   Dim bRet
   Dim objRec
   
  
   Call NewMC(False)

   ' -- Create our new level (layer) on level 10
   Call SetLevelName(DEF_LEVEL_NUMBER, DEF_PANEL)
   
   ' -- Create a new Mastercam rectangle object
   Set objRec = New McRe
  
   ' -- Assign some parameters
   With objRec
        
        .X1 = 0
        .Y1 = 0
        .X2 = 10
        .Y2 = 10
        .Z = 0

   End With
   
   ' -- Create the rectangle
   intRet = CreateRectangle(objRec, mcCOLOR_BLUE, DEF_LEVEL_NUMBER)
   
   ' -- Success?
   If intRet = mcENTITY_INVALID  Then
      ' -- Inform user of failure... 
      ShowString "Could not create rectangle"

   Else
      ' -- Chain everything possible in the specified level
      bRet = ChainAll(True, True, mcCHAIN_ALL_NUMBERED_LEVELS, DEF_PANEL)  
      
      ' -- Success?
      If bRet Then 

         Call SetContourProps()

         ' -- Apply a contoured toolpath to the rectangle
         intRet = MakeContour("Contour via VBScript", 0.5, 0, 1, mcTOOL_FLAT, mcCUTTER_COMP_OFF, mcCUTTER_ROLL_NONE , 100)
         
         ' -- Success?
         If intRet = mcENTITY_INVALID Then 
            ShowString "Could not toolpath contour"
         Else   
            ' -- Zoom All
            Call RepaintScreen(True)
            Call ClearMenuAndPrompts   
 
            ' -- All's well that ends well... 
            ShowString "Toolpath applied"
         End If
   
      Else
        ShowString "Could not chain contour"
      End If    
   End If
   

' -- Clean up
Set objRec = Nothing


End Sub




' ////////////////////
' Sub Declaration
' ////////////////////
Public Sub SetContourProps

       
        Call ClearParameters  
        
        Call SetPlaneNormal(0,0,0)   
        
        Call SetClearancePlane(True, False, 2)
        
        Call SetRetractPlane(True, False, 5)
     
        Call SetTopOfStock(False, 0)    
                
        Call SetDepth(False, -.25) 
        

End Sub

